@@ -68,11 +68,13 @@ from guake.guake_notebook import GuakeNotebook
 from guake.keybindings import Keybindings
 from guake.paths import LOCALE_DIR
 from guake.paths import SCHEMA_DIR
+from guake.paths import try_to_compile_glib_schemas
 from guake.prefs import PrefsDialog
 from guake.prefs import refresh_user_start
 from guake.settings import Settings
 from guake.simplegladeapp import SimpleGladeApp
 from guake.terminal import GuakeTerminalBox
+from guake.theme import get_gtk_theme
 from guake.theme import select_gtk_theme
 from guake.utils import get_server_time
 from locale import gettext as _
@@ -154,24 +156,32 @@ class Guake(SimpleGladeApp):
     """
 
     def __init__(self):
+
+        def load_schema():
+            return Gio.SettingsSchemaSource.new_from_directory(
+                SCHEMA_DIR, Gio.SettingsSchemaSource.get_default(), False
+            )
+
+        try:
+            schema_source = load_schema()
+        except GLib.Error:
+            log.exception("Unable to load the GLib schema, try to compile it")
+            try_to_compile_glib_schemas()
+            schema_source = load_schema()
+        self.settings = Settings(schema_source)
+        select_gtk_theme(self.settings)
+
         super(Guake, self).__init__(gladefile('guake.glade'))
 
+        self._patch_theme()
         self.add_callbacks(self)
 
-        schema_source = Gio.SettingsSchemaSource.new_from_directory(
-            SCHEMA_DIR, Gio.SettingsSchemaSource.get_default(), False
-        )
-
-        self.settings = Settings(schema_source)
         self.debug_mode = self.settings.general.get_boolean('debug-mode')
         setupLogging(self.debug_mode)
         log.info('Guake Terminal %s', guake_version())
         log.info('VTE %s', vte_version())
         log.info('Gtk %s', gtk_version())
 
-        select_gtk_theme(self.settings)
-        self._patch_theme()
-
         self.prompt_dialog = None
         self.hidden = True
         self.forceHide = False
@@ -252,14 +262,15 @@ class Guake(SimpleGladeApp):
 
         screen = self.window.get_screen()
         visual = screen.get_rgba_visual()
-        self.window.transparency = False
 
         if visual and screen.is_composited():
             self.window.set_visual(visual)
             self.window.transparency = True
         else:
             log.warn('System doesn\'t support transparency')
+            self.window.transparency = False
             self.window.set_visual(screen.get_system_visual())
+
         self.window.connect('draw', draw_callback)
 
         # It's intended to know which tab was selected to
@@ -408,24 +419,42 @@ class Guake(SimpleGladeApp):
         log.info("Guake initialized")
 
     def _patch_theme(self):
-        style_provider = Gtk.CssProvider()
-        win = Gtk.Window()
-        style_context = win.get_style_context()
+        theme_name, variant = get_gtk_theme(self.settings)
 
         def rgba_to_hex(color):
             return "#{0:02x}{1:02x}{2:02x}".format(
                 int(color.red * 255), int(color.green * 255), int(color.blue * 255)
             )
 
-        selected_bg_color = rgba_to_hex(style_context.lookup_color('theme_selected_bg_color')[1])
+        style_context = self.get_widget("window-root").get_style_context()
+        # for n in [
+        #     "inverted_bg_color",
+        #     "inverted_fg_color",
+        #     "selected_bg_color",
+        #     "selected_fg_color",
+        #     "theme_inverted_bg_color",
+        #     "theme_inverted_fg_color",
+        #     "theme_selected_bg_color",
+        #     "theme_selected_fg_color",
+        #     ]:
+        #     s = style_context.lookup_color(n)
+        #     print(n, s, rgba_to_hex(s[1]))
+        selected_fg_color = rgba_to_hex(style_context.lookup_color("theme_selected_fg_color")[1])
+        selected_bg_color = rgba_to_hex(style_context.lookup_color("theme_selected_bg_color")[1])
+        log.debug(
+            "Patching theme '%s' (prefer dark = '%r'), overriding tab 'checked' state': "
+            "foreground: %r, background: %r", theme_name, "yes"
+            if variant == "dark" else "no", selected_fg_color, selected_bg_color
+        )
         css_data = dedent(
             """
-            .tab:checked {{
-              color: white;
-              background-color: {};
+            .custom_tab:checked {{
+              color: {selected_fg_color};
+              background: {selected_bg_color};
             }}
-            """.format(selected_bg_color)
+            """.format(selected_bg_color=selected_bg_color, selected_fg_color=selected_fg_color)
         ).encode()
+        style_provider = Gtk.CssProvider()
         style_provider.load_from_data(css_data)
         Gtk.StyleContext.add_provider_for_screen(
             Gdk.Screen.get_default(), style_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION
@@ -799,6 +828,7 @@ class Guake(SimpleGladeApp):
     def show_hide(self, *args):
         """Toggles the main window visibility
         """
+        log.debug("Show_hide called")
         if self.forceHide:
             self.forceHide = False
             return
@@ -1762,7 +1792,7 @@ class Guake(SimpleGladeApp):
     def add_tab(self, directory=None):
         """Adds a new tab to the terminal notebook.
         """
-        box = GuakeTerminalBox(self.settings)
+        box = GuakeTerminalBox(self.window, self.settings)
         box.terminal.grab_focus()
         # TODO PORT port this
         # TODO PORT seems to run just fine without
@@ -1803,7 +1833,7 @@ class Guake(SimpleGladeApp):
         bnt = Gtk.RadioButton(group=parent, label=label, use_underline=False)
         bnt.set_property('can-focus', False)
         bnt.set_property('draw-indicator', False)
-        bnt.get_style_context().add_class("tab")
+        bnt.get_style_context().add_class("custom_tab")
         bnt.connect('button-press-event', self.show_tab_menu)
         bnt.connect('button-press-event', self.middle_button_click)
         bnt.connect('button-press-event', self.show_rename_current_tab_dialog)
